@@ -1,7 +1,7 @@
 package Wubot::Plugin::Command;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use Wubot::Logger;
 
@@ -82,8 +82,23 @@ Wubot::Plugin::Command - run an external command and capture the output and exit
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 DESCRIPTION
 
 TODO: More to come...
+
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item check( $inputs )
+
+The standard monitor check() method.
+
+=item validate_config( $config )
+
+The standard monitor validate_config() method.
+
+=back
