@@ -1,7 +1,7 @@
 package Wubot::Plugin::MoonPhase;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use Astro::MoonPhase;
 
@@ -73,7 +73,7 @@ Wubot::Plugin::MoonPhase - monitor the phase of the moon
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 SYNOPSIS
 
@@ -87,3 +87,14 @@ version 0.2_002
 
 Reports the amount of time remaining until the next full or new moon,
 whichever is closer.
+
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item check( $inputs )
+
+The standard monitor check() method.
+
+=back
