@@ -1,7 +1,7 @@
 package Wubot::Plugin::OsxMailApp;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use Date::Manip;
 
@@ -113,8 +113,19 @@ Wubot::Plugin::OsxMailApp - monitor OS X mailbox file for new messages
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 DESCRIPTION
 
 TODO: More to come...
+
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item check( $inputs )
+
+The standard monitor check() method.
+
+=back
