@@ -1,7 +1,7 @@
 package Wubot::Plugin::RSS;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use XML::Feed;
 
@@ -118,7 +118,7 @@ Wubot::Plugin::RSS - monitor an RSS feed
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 SYNOPSIS
 
@@ -182,3 +182,14 @@ items in the feed to be sent again.
 =head1 SEE ALSO
 
 This plugin uses L<Wubot::Util::WebFetcher>.
+
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item check( $inputs )
+
+The standard monitor check() method.
+
+=back
