@@ -1,7 +1,7 @@
 package Wubot::Plugin::TaskDB;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use DBI;
 use POSIX qw(strftime);
@@ -66,8 +66,19 @@ Wubot::Plugin::TaskDB - monitor the highest priority task in the task db
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 DESCRIPTION
 
 TODO: More to come...
+
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item check( $inputs )
+
+The standard monitor check() method.
+
+=back
