@@ -1,7 +1,7 @@
 package Wubot::Plugin::WebFetch;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 # todo: select with xpath in addition to regexp
 
@@ -54,7 +54,7 @@ Wubot::Plugin::WebFetch - fetch content from a URL
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 SYNOPSIS
 
@@ -167,3 +167,14 @@ RRD:
 =head1 SEE ALSO
 
 This plugin uses L<Wubot::Util::WebFetcher>.
+
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item check( $inputs )
+
+The standard monitor check() method.
+
+=back
