@@ -1,7 +1,7 @@
 package Wubot::Reactor::CaptureData;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 # todo: enable using Regexp::Common regexps here
 
@@ -45,7 +45,7 @@ Wubot::Reactor::CaptureData - capture data from a field using a regexp
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 SYNOPSIS
 
@@ -68,3 +68,13 @@ version 0.2_002
     config:
       field: x
       regexp: '([\d\.]+),'
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item react( $message, $config )
+
+The standard reactor plugin react() method.
+
+=back
