@@ -1,7 +1,7 @@
 package Wubot::Reactor::Console;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use POSIX qw(strftime);
 use Term::ANSIColor;
@@ -85,7 +85,7 @@ Wubot::Reactor::Console - display a notification to stdout
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 SYNOPSIS
 
@@ -96,3 +96,13 @@ version 0.2_002
 =head1 DESCRIPTION
 
 For more information, please see the 'notifications' document.
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item react( $message, $config )
+
+The standard reactor plugin react() method.
+
+=back
