@@ -1,7 +1,7 @@
 package Wubot::Reactor::GreaterThan;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use YAML;
 
@@ -48,7 +48,7 @@ Wubot::Reactor::GreaterThan - set keys and values if the value of a field exceed
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 DESCRIPTION
 
@@ -66,3 +66,13 @@ reactor plugin:
         key2: value2
 
 See the 'conditions' document for more information.
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item react( $message, $config )
+
+The standard reactor plugin react() method.
+
+=back
