@@ -1,7 +1,7 @@
 package Wubot::Reactor::HashLookup;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use Wubot::Logger;
 
@@ -21,18 +21,15 @@ sub react {
 
 1;
 
-
 __END__
 
-
 =head1 NAME
 
 Wubot::Reactor::HashLookup - map the value of one field to a value for another using a lookup table
 
-
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 SYNOPSIS
 
@@ -51,3 +48,13 @@ version 0.2_002
 
 Look up the value for a target field in a configured hash using the
 value of another field as the key.
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item react( $message, $config )
+
+The standard reactor plugin react() method.
+
+=back
