@@ -1,7 +1,7 @@
 package Wubot::Reactor::SetField;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use YAML;
 
@@ -58,7 +58,7 @@ Wubot::Reactor::SetField - set one or more fields on the message to a configured
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 SYNOPSIS
 
@@ -76,3 +76,13 @@ version 0.2_002
         x: 123
         y: 456
         z: 789
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item react( $message, $config )
+
+The standard reactor plugin react() method.
+
+=back
