@@ -1,7 +1,7 @@
 package Wubot::Reactor::Template;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use Text::Template;
 use YAML;
@@ -57,3 +57,28 @@ sub react {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Wubot::Reactor::Template - build a field using existing message fields as a template
+
+=head1 VERSION
+
+version 0.2_003
+
+=head1 DESCRIPTION
+
+TODO: More to come...
+
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item react( $message, $config )
+
+The standard reactor plugin react() method.
+
+=back
