@@ -1,7 +1,7 @@
 package Wubot::Reactor::WebFetch;
 use Moose;
 
-our $VERSION = '0.2_002'; # VERSION
+our $VERSION = '0.2_003'; # VERSION
 
 use YAML;
 
@@ -83,7 +83,7 @@ Wubot::Reactor::WebFetch - fetch data from a URL
 
 =head1 VERSION
 
-version 0.2_002
+version 0.2_003
 
 =head1 SYNOPSIS
 
@@ -108,3 +108,13 @@ retrieved content is stored on the message in the configured 'field'.
 If an error occurs, the error will be logged at 'error' level.
 
 The retrieved content will be utf8 decoded.
+
+=head1 SUBROUTINES/METHODS
+
+=over 8
+
+=item react( $message, $config )
+
+The standard reactor plugin react() method.
+
+=back
